"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loadableLib = exports.loadableTimeout = exports.loadableDelay = exports.loadable = void 0;

var _component = _interopRequireDefault(require("@loadable/component"));

var _pMinDelay = _interopRequireDefault(require("p-min-delay"));

var _promiseTimeout = require("promise-timeout");

var _LoadSpinner = require("./LoadSpinner");

// https://www.smooth-code.com/open-source/loadable-components/

/**
 * 组件导入函数,支持自定义加载动画
 * @param {Function} func 返回动态引入的函数, 如 ()=>import('./a/b/c')
 * @param {Function} spinner 加载的的loading, 默认为loadSpinner
 * @returns {Component}
 */
var loadable = function loadable(func, spinner) {
  return (0, _component.default)(func, {
    fallback: (0, _LoadSpinner.loadSpinner)(spinner)
  });
};
/**
 * 组件导入函数,支持延时加载
 * @param {Promise} promise 动态引入的返回值, 如 import('./a/b/c')
 * @param {Number} delay 延迟时间, 默认200ms
 * @param {Function} spinner 加载的的loading, 默认为loadSpinner
 * @returns {Component}
 */


exports.loadable = loadable;

var loadableDelay = function loadableDelay(promise) {
  var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 200;
  var spinner = arguments.length > 2 ? arguments[2] : undefined;
  return (0, _component.default)(function () {
    return (0, _pMinDelay.default)(promise, delay);
  }, {
    fallback: (0, _LoadSpinner.loadSpinner)(spinner)
  });
};
/**
 * 组件导入函数,支持加载超时
 * @param {Promise} promise 动态引入的返回值, 如 import('./a/b/c')
 * @param {Number} time 过期时间, 默认5000ms
 * @param {Function} spinner 加载的的loading, 默认为loadSpinner
 * @returns {Component}
 */


exports.loadableDelay = loadableDelay;

var loadableTimeout = function loadableTimeout(promise) {
  var time = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 5000;
  var spinner = arguments.length > 2 ? arguments[2] : undefined;
  return (0, _component.default)(function () {
    return (0, _promiseTimeout.timeout)(promise, time);
  }, {
    fallback: (0, _LoadSpinner.loadSpinner)(spinner)
  });
};
/**
 * lib动态导入函数
 * @param {Function} func 返回动态引入的函数, 如 ()=>import('abc')
 */


exports.loadableTimeout = loadableTimeout;
var loadableLib = _component.default.lib;
exports.loadableLib = loadableLib;